@@ -15,9 +15,9 @@ import os # delete
 
 # Additional Resources
 
-import junipercs.resources.commands_list as cmd_list_file 
-import junipercs.system_parser.tokens as tokens_file
-import junipercs.system_parser.tokens_definition 
+import junipercs.resources.commands_list.cmdList as cmdList
+import junipercs.system_parser.tokens.tokens as tokens
+import junipercs.system_parser.tokens_definition
 
 # Commands
 
@@ -34,14 +34,6 @@ import junipercs.modules.list as list_cmd
 
 varMemory = {}
 
-# Commands List
-
-cmdList = cmd_list_file.cmdList
-
-# System Tokens
-
-tokens = tokens_file.tokens
-
 # Auxiliary Checks
 
 checkString = False
